export * from './service.ts';
export * from './types.ts';
import { type CreateScheduleParams, type UpdateScheduleParams, type CreateScheduleDestinationParams, type ScheduleGetResult, type ScheduleListResult, type ScheduleCreateResult, type ScheduleDeliveryListResult, type Schedule, type ScheduleDestination } from './service.ts';
import { type Logger } from '@agentuity/client';
import { z } from 'zod';
export declare const ScheduleClientOptionsSchema: z.ZodObject<{
    apiKey: z.ZodOptional<z.ZodString>;
    url: z.ZodOptional<z.ZodString>;
    orgId: z.ZodOptional<z.ZodString>;
    logger: z.ZodOptional<z.ZodCustom<Logger, Logger>>;
}, z.core.$strip>;
export type ScheduleClientOptions = z.infer<typeof ScheduleClientOptionsSchema>;
export declare class ScheduleClient {
    #private;
    constructor(options?: ScheduleClientOptions);
    create(params: CreateScheduleParams): Promise<ScheduleCreateResult>;
    list(params?: {
        limit?: number;
        offset?: number;
    }): Promise<ScheduleListResult>;
    get(scheduleId: string): Promise<ScheduleGetResult>;
    update(scheduleId: string, params: UpdateScheduleParams): Promise<{
        schedule: Schedule;
    }>;
    delete(scheduleId: string): Promise<void>;
    createDestination(scheduleId: string, params: CreateScheduleDestinationParams): Promise<{
        destination: ScheduleDestination;
    }>;
    deleteDestination(destinationId: string): Promise<void>;
    listDeliveries(scheduleId: string, params?: {
        limit?: number;
        offset?: number;
    }): Promise<ScheduleDeliveryListResult>;
}
//# sourceMappingURL=index.d.ts.map