declare const service: {
    name: string;
    slug: string;
    description: string;
    endpoints: ({
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    name: import("zod").ZodString;
                    description: import("zod").ZodOptional<import("zod").ZodString>;
                    expression: import("zod").ZodString;
                    internal: import("zod").ZodOptional<import("zod").ZodBoolean>;
                    destinations: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodLazy<import("zod").ZodObject<{
                        type: import("zod").ZodEnum<{
                            url: "url";
                            sandbox: "sandbox";
                        }>;
                        config: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>;
                    }, import("zod/v4/core").$strip>>>>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                schedule: import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    created_at: import("zod").ZodString;
                    updated_at: import("zod").ZodString;
                    created_by: import("zod").ZodString;
                    name: import("zod").ZodString;
                    description: import("zod").ZodNullable<import("zod").ZodString>;
                    expression: import("zod").ZodString;
                    due_date: import("zod").ZodString;
                    internal: import("zod").ZodBoolean;
                }, import("zod/v4/core").$strip>;
                destinations: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    schedule_id: import("zod").ZodString;
                    created_at: import("zod").ZodString;
                    updated_at: import("zod").ZodString;
                    created_by: import("zod").ZodString;
                    type: import("zod").ZodEnum<{
                        url: "url";
                        sandbox: "sandbox";
                    }>;
                    config: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>;
                }, import("zod/v4/core").$strip>>;
            }, import("zod/v4/core").$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            expression: string;
            destinations: {
                type: string;
                config: {
                    url: string;
                };
            }[];
            type?: undefined;
            config?: undefined;
        };
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                schedules: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    created_at: import("zod").ZodString;
                    updated_at: import("zod").ZodString;
                    created_by: import("zod").ZodString;
                    name: import("zod").ZodString;
                    description: import("zod").ZodNullable<import("zod").ZodString>;
                    expression: import("zod").ZodString;
                    due_date: import("zod").ZodString;
                    internal: import("zod").ZodBoolean;
                }, import("zod/v4/core").$strip>>;
                total: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                schedule: import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    created_at: import("zod").ZodString;
                    updated_at: import("zod").ZodString;
                    created_by: import("zod").ZodString;
                    name: import("zod").ZodString;
                    description: import("zod").ZodNullable<import("zod").ZodString>;
                    expression: import("zod").ZodString;
                    due_date: import("zod").ZodString;
                    internal: import("zod").ZodBoolean;
                }, import("zod/v4/core").$strip>;
                destinations: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    schedule_id: import("zod").ZodString;
                    created_at: import("zod").ZodString;
                    updated_at: import("zod").ZodString;
                    created_by: import("zod").ZodString;
                    type: import("zod").ZodEnum<{
                        url: "url";
                        sandbox: "sandbox";
                    }>;
                    config: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>;
                }, import("zod/v4/core").$strip>>;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    name: import("zod").ZodOptional<import("zod").ZodString>;
                    description: import("zod").ZodOptional<import("zod").ZodString>;
                    expression: import("zod").ZodOptional<import("zod").ZodString>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                schedule: import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    created_at: import("zod").ZodString;
                    updated_at: import("zod").ZodString;
                    created_by: import("zod").ZodString;
                    name: import("zod").ZodString;
                    description: import("zod").ZodNullable<import("zod").ZodString>;
                    expression: import("zod").ZodString;
                    due_date: import("zod").ZodString;
                    internal: import("zod").ZodBoolean;
                }, import("zod/v4/core").$strip>;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            expression: string;
            name?: undefined;
            destinations?: undefined;
            type?: undefined;
            config?: undefined;
        };
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        responseFields?: undefined;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    type: import("zod").ZodEnum<{
                        url: "url";
                        sandbox: "sandbox";
                    }>;
                    config: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                destination: import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    schedule_id: import("zod").ZodString;
                    created_at: import("zod").ZodString;
                    updated_at: import("zod").ZodString;
                    created_by: import("zod").ZodString;
                    type: import("zod").ZodEnum<{
                        url: "url";
                        sandbox: "sandbox";
                    }>;
                    config: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>;
                }, import("zod/v4/core").$strip>;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            type: string;
            config: {
                url: string;
                method: string;
            };
            name?: undefined;
            expression?: undefined;
            destinations?: undefined;
        };
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                deliveries: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    date: import("zod").ZodString;
                    schedule_id: import("zod").ZodString;
                    schedule_destination_id: import("zod").ZodString;
                    status: import("zod").ZodEnum<{
                        success: "success";
                        pending: "pending";
                        failed: "failed";
                    }>;
                    retries: import("zod").ZodNumber;
                    error: import("zod").ZodNullable<import("zod").ZodString>;
                    response: import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>;
                }, import("zod/v4/core").$strip>>;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    })[];
};
export default service;
//# sourceMappingURL=api-reference.d.ts.map